@@ -1,9 +1,8 @@
 package LWP::Authen::Ntlm;
 
 use strict;
-use vars qw/$VERSION/;
 
-$VERSION = "6.12";
+our $VERSION = "6.16";
 
 use Authen::NTLM "1.02";
 use MIME::Base64 "2.12";
@@ -90,7 +89,9 @@ sub authenticate {
 }
 
 1;
+__END__
 
+=pod
 
 =head1 NAME
 
@@ -116,7 +117,7 @@ LWP::Authen::Ntlm - Library for enabling NTLM authentication (Microsoft) in LWP
 
 =head1 DESCRIPTION
 
-C<LWP::Authen::Ntlm> allows LWP to authenticate against servers that are using the 
+L<LWP::Authen::Ntlm> allows LWP to authenticate against servers that are using the 
 NTLM authentication scheme popularized by Microsoft.  This type of authentication is 
 common on intranets of Microsoft-centric organizations.
 
@@ -178,3 +179,5 @@ under the same terms as Perl itself.
 =head1 SEE ALSO
 
 L<LWP>, L<LWP::UserAgent>, L<lwpcook>.
+
+=cut
