@@ -1,8 +1,7 @@
 package LWP::RobotUA;
 
-require LWP::UserAgent;
-@ISA = qw(LWP::UserAgent);
-$VERSION = "6.13";
+use base qw(LWP::UserAgent);
+our $VERSION = "6.16";
 
 require WWW::RobotRules;
 require HTTP::Request;
@@ -190,6 +189,8 @@ sub as_string
 
 __END__
 
+=pod
+
 =head1 NAME
 
 LWP::RobotUA - a class for well-behaved Web robots
@@ -301,3 +302,5 @@ Copyright 1996-2004 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
+
+=cut
