@@ -1,11 +1,9 @@
 package LWP::UserAgent;
 
 use strict;
-use vars qw(@ISA $VERSION);
 
-require LWP::MemberMixin;
-@ISA = qw(LWP::MemberMixin);
-$VERSION = "6.15";
+use base qw(LWP::MemberMixin);
+our $VERSION = "6.16";
 
 use HTTP::Request ();
 use HTTP::Response ();
@@ -20,8 +18,8 @@ use Carp ();
 sub new
 {
     # Check for common user mistake
-    Carp::croak("Options to LWP::UserAgent should be key/value pairs, not hash reference") 
-        if ref($_[1]) eq 'HASH'; 
+    Carp::croak("Options to LWP::UserAgent should be key/value pairs, not hash reference")
+        if ref($_[1]) eq 'HASH';
 
     my($class, %cnf) = @_;
 
@@ -69,13 +67,13 @@ sub new
     my $cookie_jar = delete $cnf{cookie_jar};
     my $conn_cache = delete $cnf{conn_cache};
     my $keep_alive = delete $cnf{keep_alive};
-    
+
     Carp::croak("Can't mix conn_cache and keep_alive")
 	  if $conn_cache && $keep_alive;
 
     my $protocols_allowed   = delete $cnf{protocols_allowed};
     my $protocols_forbidden = delete $cnf{protocols_forbidden};
-    
+
     my $requests_redirectable = delete $cnf{requests_redirectable};
     $requests_redirectable = ['GET', 'HEAD']
       unless defined $requests_redirectable;
@@ -303,7 +301,7 @@ sub request
 
 	# These headers should never be forwarded
 	$referral->remove_header('Host', 'Cookie');
-	
+
 	if ($referral->header('Referer') &&
 	    $request->uri->scheme eq 'https' &&
 	    $referral->uri->scheme eq 'http')
@@ -314,7 +312,7 @@ sub request
 	}
 
 	if ($code == &HTTP::Status::RC_SEE_OTHER ||
-	    $code == &HTTP::Status::RC_FOUND) 
+	    $code == &HTTP::Status::RC_FOUND)
         {
 	    my $method = uc($referral->method);
 	    unless ($method eq "GET" || $method eq "HEAD") {
@@ -350,7 +348,7 @@ sub request
 	    ?  "Proxy-Authenticate" : "WWW-Authenticate";
 	my @challenge = $response->header($ch_header);
 	unless (@challenge) {
-	    $response->header("Client-Warning" => 
+	    $response->header("Client-Warning" =>
 			      "Missing Authenticate header");
 	    return $response;
 	}
@@ -364,7 +362,7 @@ sub request
 	    $challenge = { @$challenge };  # make rest into a hash
 
 	    unless ($scheme =~ /^([a-z]+(?:-[a-z]+)*)$/) {
-		$response->header("Client-Warning" => 
+		$response->header("Client-Warning" =>
 				  "Bad authentication scheme '$scheme'");
 		return $response;
 	    }
@@ -411,12 +409,47 @@ sub get {
     return $self->request( HTTP::Request::Common::GET( @parameters ), @suff );
 }
 
+sub _has_raw_content {
+    my $self = shift;
+    shift; # drop url
+
+    # taken from HTTP::Request::Common::request_type_with_data
+    my $content;
+    $content = shift if @_ and ref $_[0];
+    my($k, $v);
+    while (($k,$v) = splice(@_, 0, 2)) {
+        if (lc($k) eq 'content') {
+            $content = $v;
+        }
+    }
+
+    # We were given Content => 'string' ...
+    if (defined $content && ! ref ($content)) {
+        return 1;
+    }
+
+    return;
+}
+
+sub _maybe_copy_default_content_type {
+    my ($self, $req, @parameters) = @_;
+
+    # If we have a default Content-Type and someone passes in a POST/PUT
+    # with Content => 'some-string-value', use that Content-Type instead
+    # of x-www-form-urlencoded
+    my $ct = $self->default_header('Content-Type');
+    return unless defined $ct && $self->_has_raw_content(@parameters);
+
+    $req->header('Content-Type' => $ct);
+}
 
 sub post {
     require HTTP::Request::Common;
     my($self, @parameters) = @_;
     my @suff = $self->_process_colonic_headers(\@parameters, (ref($parameters[1]) ? 2 : 1));
-    return $self->request( HTTP::Request::Common::POST( @parameters ), @suff );
+    my $req = HTTP::Request::Common::POST(@parameters);
+    $self->_maybe_copy_default_content_type($req, @parameters);
+    return $self->request($req, @suff);
 }
 
 
@@ -432,7 +465,9 @@ sub put {
     require HTTP::Request::Common;
     my($self, @parameters) = @_;
     my @suff = $self->_process_colonic_headers(\@parameters, (ref($parameters[1]) ? 2 : 1));
-    return $self->request( HTTP::Request::Common::PUT( @parameters ), @suff );
+    my $req = HTTP::Request::Common::PUT(@parameters);
+    $self->_maybe_copy_default_content_type($req, @parameters);
+    return $self->request($req, @suff);
 }
 
 
@@ -460,7 +495,7 @@ sub _process_colonic_headers {
 	    Carp::croak("A :content_cb value can't be undef") unless defined $arg;
 	    Carp::croak("A :content_cb value must be a coderef")
 		unless ref $arg and UNIVERSAL::isa($arg, 'CODE');
-	    
+
 	}
 	elsif ($args->[$i] eq ':content_file') {
 	    $arg = $args->[$i + 1];
@@ -588,13 +623,13 @@ sub redirect_ok
     my $method = $response->request->method;
     return 0 unless grep $_ eq $method,
       @{ $self->requests_redirectable || [] };
-    
+
     if ($new_request->uri->scheme eq 'file') {
       $response->header("Client-Warning" =>
 			"Can't redirect to a file:// URL!");
       return 0;
     }
-    
+
     # Otherwise it's apparently okay...
     return 1;
 }
@@ -917,7 +952,7 @@ sub mirror
     }
 
     # Only fetching a fresh copy of the would be considered success.
-    # If the file was not modified, "304" would returned, which 
+    # If the file was not modified, "304" would returned, which
     # is considered by HTTP::Status to be a "redirect", /not/ "success"
     if ( $response->is_success ) {
         my @stat        = stat($tmpfile) or die "Could not stat tmpfile '$tmpfile': $!";
@@ -932,7 +967,7 @@ sub mirror
             unlink($tmpfile);
             die "Content-length mismatch: " . "expected $content_length bytes, got $file_length\n";
         }
-        # The file was the expected length. 
+        # The file was the expected length.
         else {
             # Replace the stale file with a fresh copy
             if ( -e $file ) {
@@ -949,7 +984,7 @@ sub mirror
             }
         }
     }
-    # The local copy is fresh enough, so just delete the temp file  
+    # The local copy is fresh enough, so just delete the temp file
     else {
 	unlink($tmpfile);
     }
@@ -1052,6 +1087,8 @@ sub _new_response {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 LWP::UserAgent - Web user agent class
@@ -1059,13 +1096,13 @@ LWP::UserAgent - Web user agent class
 =head1 SYNOPSIS
 
  require LWP::UserAgent;
- 
+
  my $ua = LWP::UserAgent->new;
  $ua->timeout(10);
  $ua->env_proxy;
- 
+
  my $response = $ua->get('http://search.cpan.org/');
- 
+
  if ($response->is_success) {
      print $response->decoded_content;  # or whatever
  }
@@ -1075,22 +1112,22 @@ LWP::UserAgent - Web user agent class
 
 =head1 DESCRIPTION
 
-The C<LWP::UserAgent> is a class implementing a web user agent.
-C<LWP::UserAgent> objects can be used to dispatch web requests.
+The L<LWP::UserAgent> is a class implementing a web user agent.
+L<LWP::UserAgent> objects can be used to dispatch web requests.
 
-In normal use the application creates an C<LWP::UserAgent> object, and
+In normal use the application creates an L<LWP::UserAgent> object, and
 then configures it with values for timeouts, proxies, name, etc. It
-then creates an instance of C<HTTP::Request> for the request that
+then creates an instance of L<HTTP::Request> for the request that
 needs to be performed. This request is then passed to one of the
 request method the UserAgent, which dispatches it using the relevant
-protocol, and returns a C<HTTP::Response> object.  There are
+protocol, and returns a L<HTTP::Response> object.  There are
 convenience methods for sending the most common request types: get(),
 head(), post(), put() and delete().  When using these methods then the
 creation of the request object is hidden as shown in the synopsis above.
 
 The basic approach of the library is to use HTTP style communication
 for all protocol schemes.  This means that you will construct
-C<HTTP::Request> objects and receive C<HTTP::Response> objects even
+L<HTTP::Request> objects and receive L<HTTP::Response> objects even
 for non-HTTP resources like I<gopher> and I<ftp>.  In order to achieve
 even more similarity to HTTP style communications, gopher menus and
 file directories are converted to HTML documents.
@@ -1103,7 +1140,7 @@ The following constructor methods are available:
 
 =item $ua = LWP::UserAgent->new( %options )
 
-This method constructs a new C<LWP::UserAgent> object and returns it.
+This method constructs a new L<LWP::UserAgent> object and returns it.
 Key/value pair arguments may be provided to set up the initial state.
 The following options correspond to attribute methods described below:
 
@@ -1141,7 +1178,7 @@ Returns a copy of the LWP::UserAgent object.
 =head1 ATTRIBUTES
 
 The settings of the configuration attributes modify the behaviour of the
-C<LWP::UserAgent> when it dispatches requests.  Most of these can also
+L<LWP::UserAgent> when it dispatches requests.  Most of these can also
 be initialized by options passed to the constructor method.
 
 The following attribute methods are provided.  The attribute value is
@@ -1199,7 +1236,7 @@ Get/set the cookie jar object to use.  The only requirement is that
 the cookie jar object must implement the extract_cookies($response) and
 add_cookie_header($request) methods.  These methods will then be
 invoked by the user agent as requests are sent and responses are
-received.  Normally this will be a C<HTTP::Cookies> object or some
+received.  Normally this will be a L<HTTP::Cookies> object or some
 subclass.
 
 The default is to have no cookie_jar, i.e. never automatically add
@@ -1207,8 +1244,8 @@ The default is to have no cookie_jar, i.e. never automatically add
 
 Shortcut: If a reference to a plain hash is passed in as the
 $cookie_jar_object, then it is replaced with an instance of
-C<HTTP::Cookies> that is initialized based on the hash.  This form also
-automatically loads the C<HTTP::Cookies> module.  It means that:
+L<HTTP::Cookies> that is initialized based on the hash.  This form also
+automatically loads the L<HTTP::Cookies> module.  It means that:
 
   $ua->cookie_jar({ file => "$ENV{HOME}/.cookies.txt" });
 
@@ -1222,7 +1259,7 @@ is really just a shortcut for:
 =item $ua->default_headers( $headers_obj )
 
 Get/set the headers object that will provide default header values for
-any requests sent.  By default this will be an empty C<HTTP::Headers>
+any requests sent.  By default this will be an empty L<HTTP::Headers>
 object.
 
 =item $ua->default_header( $field )
@@ -1239,7 +1276,7 @@ $value ). Example:
 
 =item $ua->conn_cache( $cache_obj )
 
-Get/set the C<LWP::ConnCache> object to use.  See L<LWP::ConnCache>
+Get/set the L<LWP::ConnCache> object to use.  See L<LWP::ConnCache>
 for details.
 
 =item $ua->credentials( $netloc, $realm )
@@ -1302,12 +1339,12 @@ This reads (or sets) this user agent's list of protocols that the
 request methods will exclusively allow.  The protocol names are case
 insensitive.
 
-For example: C<$ua-E<gt>protocols_allowed( [ 'http', 'https'] );>
+For example: C<< $ua->protocols_allowed( [ 'http', 'https'] ); >>
 means that this user agent will I<allow only> those protocols,
 and attempts to use this user agent to access URLs with any other
 schemes (like "ftp://...") will result in a 500 error.
 
-To delete the list, call: C<$ua-E<gt>protocols_allowed(undef)>
+To delete the list, call: C<< $ua->protocols_allowed(undef) >>
 
 By default, an object has neither a C<protocols_allowed> list, nor a
 C<protocols_forbidden> list.
@@ -1323,19 +1360,19 @@ This reads (or sets) this user agent's list of protocols that the
 request method will I<not> allow. The protocol names are case
 insensitive.
 
-For example: C<$ua-E<gt>protocols_forbidden( [ 'file', 'mailto'] );>
+For example: C<< $ua->protocols_forbidden( [ 'file', 'mailto'] ); >>
 means that this user agent will I<not> allow those protocols, and
 attempts to use this user agent to access URLs with those schemes
 will result in a 500 error.
 
-To delete the list, call: C<$ua-E<gt>protocols_forbidden(undef)>
+To delete the list, call: C<< $ua->protocols_forbidden(undef) >>
 
 =item $ua->requests_redirectable
 
 =item $ua->requests_redirectable( \@requests )
 
 This reads or sets the object's list of request names that
-C<$ua-E<gt>redirect_ok(...)> will allow redirection for.  By
+C<< $ua->redirect_ok(...) >> will allow redirection for.  By
 default, this is C<['GET', 'HEAD']>, as per RFC 2616.  To
 change to include 'POST', consider:
 
@@ -1426,7 +1463,7 @@ Set/retrieve proxy URL for a scheme:
  $ua->proxy(['http', 'ftp'], 'http://proxy.sn.no:8001/');
  $ua->proxy('gopher', 'http://proxy.sn.no:8001/');
 
-The first form specifies that the URL is to be used for proxying of
+The first form specifies that the URL is to be used as a proxy for
 access methods listed in the list in the first method argument,
 i.e. 'http' and 'ftp'.
 
@@ -1436,7 +1473,7 @@ proxy URL for a single access scheme.
 =item $ua->no_proxy( $domain, ... )
 
 Do not proxy requests to the given domains.  Calling no_proxy without
-any domains clears the list of domains. Eg:
+any domains clears the list of domains. For example:
 
  $ua->no_proxy('localhost', 'example.com');
 
@@ -1627,7 +1664,10 @@ object itself.  This might not be suitable for very large response
 bodies.  Only one of C<:content_file> or C<:content_cb> can be
 specified.  The content of unsuccessful responses will always
 accumulate in the response object itself, regardless of the
-C<:content_file> or C<:content_cb> options passed in.
+C<:content_file> or C<:content_cb> options passed in.  Note that errors
+writing to the content file (for example due to permission denied
+or the filesystem being full) will be reported via the C<Client-Aborted>
+or C<X-Died> response headers, and not the C<is_success> method.
 
 The C<:read_size_hint> option is passed to the protocol module which
 will try to read data from the server in chunks of this size.  A
@@ -1664,7 +1704,7 @@ This method will dispatch a C<POST> request on the given $url, with
 content. Additional headers and content options are the same as for
 the get() method.
 
-This method will use the POST() function from C<HTTP::Request::Common>
+This method will use the POST() function from L<HTTP::Request::Common>
 to build the request.  See L<HTTP::Request::Common> for a details on
 how to pass form content and other advanced features.
 
@@ -1685,7 +1725,7 @@ This method will dispatch a C<PUT> request on the given $url, with
 content. Additional headers and content options are the same as for
 the get() method.
 
-This method will use the PUT() function from C<HTTP::Request::Common>
+This method will use the PUT() function from L<HTTP::Request::Common>
 to build the request.  See L<HTTP::Request::Common> for a details on
 how to pass form content and other advanced features.
 
@@ -1696,7 +1736,7 @@ how to pass form content and other advanced features.
 This method will dispatch a C<DELETE> request on the given $url.  Additional
 headers and content options are the same as for the get() method.
 
-This method will use the DELETE() function from C<HTTP::Request::Common>
+This method will use the DELETE() function from L<HTTP::Request::Common>
 to build the request.  See L<HTTP::Request::Common> for a details on
 how to pass form content and other advanced features.
 
@@ -1721,7 +1761,7 @@ The return value is the response object.
 =item $ua->request( $request, $content_cb, $read_size_hint )
 
 This method will dispatch the given $request object.  Normally this
-will be an instance of the C<HTTP::Request> class, but any object with
+will be an instance of the L<HTTP::Request> class, but any object with
 a similar interface will do.  The return value is a response object.
 See L<HTTP::Request> and L<HTTP::Response> for a description of the
 interface provided by these classes.
@@ -1736,7 +1776,10 @@ They are convenience methods that simply hides the creation of the
 request object for you.
 
 The $content_file, $content_cb and $read_size_hint all correspond to
-options described with the get() method above.
+options described with the get() method above.  Note that errors
+writing to the content file (for example due to permission denied
+or the filesystem being full) will be reported via the C<Client-Aborted>
+or C<X-Died> response headers, and not the C<is_success> method.
 
 You are allowed to use a CODE reference as C<content> in the request
 object passed in.  The C<content> function should return the content
@@ -1782,7 +1825,7 @@ object.
 =head2 Callback methods
 
 The following methods will be invoked as requests are processed. These
-methods are documented here because subclasses of C<LWP::UserAgent>
+methods are documented here because subclasses of L<LWP::UserAgent>
 might want to override their behaviour.
 
 =over
@@ -1851,7 +1894,7 @@ message objects dispatched and received.  See L<HTTP::Request::Common>
 and L<HTML::Form> for other ways to build request objects.
 
 See L<WWW::Mechanize> and L<WWW::Search> for examples of more
-specialized user agents based on C<LWP::UserAgent>.
+specialized user agents based on L<LWP::UserAgent>.
 
 =head1 COPYRIGHT
 
@@ -1859,3 +1902,5 @@ Copyright 1995-2009 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
+
+=cut
